==> contrib_toggle-6.x-1.0.tar.gz: contrib_toggle/contrib_toggle.js <==
// $Id$

/**
 * Kudos to starbow for Quick Admin Modules; much of the current code was retooled 
 * from there for the current purpose. http://drupal.org/project/qamodules
 */

/**
 * Activate a module and any modules it depends on.
 */
Drupal.contribToggleActivate = function (title, modules) {
  modules[title].self.attr('checked', true);
  jQuery.each(modules[title].dependencies, function(i, val) {
    Drupal.contribToggleActivate(val, modules);
  });
}

/**
 * Deactivate a module and all the modules that depend on it.
 */
Drupal.contribToggleDeactivate = function (title, modules) {
  modules[title].self.attr('checked', false);
  jQuery.each(modules[title].requirements, function(i, val) {
    Drupal.contribToggleDeactivate(val, modules);
  });
}

/**
 * Parse a module's Required by, or Depends on string.
 *
 * @param: str - ex: 'Required by: Event Views (disabled), Views UI (disabled)'
 * @return: array - ex: ['Event Views', 'Views UI']
 */
Drupal.contribToggleParse = function(str) {
  var result = [];
  if (str) {
    str = str.substr(str.indexOf(':')+1); // Remove 'Required by:'
    str = str.replace( /\([^)]*\)/g, ''); // Remove (stuff).
    result = jQuery.map(str.split(','), function(n,i) {
      return jQuery.trim(n);
    });
  }
  return result;
}

Drupal.contribToggleSwitch = function () {
  // Read dependencies for all modules.
  var modules = [];
  $('#system-modules input:checkbox').each( function() {
    var $row = $(this).parents('tr:first');
    var $title = $row.find('label:last').text();
    var $depend = Drupal.contribToggleParse($row.find('.admin-dependencies').text());
    var $required = Drupal.contribToggleParse($row.find('.admin-required').text());
    modules[$title] = { self: $(this), dependencies : $depend, requirements : $required }
  });

  // Disable each non-core module, and any modules that depend on it.
  $('#system-modules input:checkbox').each( function() {
    // Identify package that module belongs to.
    var fieldsetLegend = $(this).parents('fieldset').find('legend').text();
    // Mark to be disabled all modules not in packages listed as cases.
    switch (fieldsetLegend) {
      case "Core - optional":
        break;
        
      case "Core - required":
        break;

      default:
        var title = $(this).parents('tr:first').find('label:last').text();
        Drupal.contribToggleDeactivate(title, modules);
    }
  });
}

if( Drupal.jsEnabled ) {
  $(document).ready(function(){ 
	var modules = [];
	$('#system-modules input:checkbox').each( function() {
	  var $row = $(this).parents('tr:first');
	  var $title = $row.find('label:last').text();
	  var $depend = Drupal.contribToggleParse($row.find('.admin-dependencies').text());
	  var $required = Drupal.contribToggleParse($row.find('.admin-required').text());
	  modules[$title] = { self: $(this), dependencies : $depend, requirements : $required }
	});
	$('#system-modules input:checkbox').click( function() {
	  var title = $(this).parents('tr:first').find('label:last').text();
	  var checked = $(this).attr('checked');
	  if (checked) { 
	    Drupal.contribToggleActivate(title, modules);
	  }
	  else {
	    Drupal.contribToggleDeactivate(title, modules);    
	  }
    });
  $(':checkbox:disabled').attr('disabled', false);
  });
}

==> contrib_toggle-6.x-1.1.tar.gz: contrib_toggle/contrib_toggle.js <==
// $Id$

/**
 * Kudos to starbow for Quick Admin Modules; much of the current code was retooled 
 * from there for the current purpose. http://drupal.org/project/qamodules
 */

/**
 * Activate a module and any modules it depends on.
 */
Drupal.contribToggleActivate = function (title, modules) {
  modules[title].self.attr('checked', true);
  jQuery.each(modules[title].dependencies, function(i, val) {
    Drupal.contribToggleActivate(val, modules);
  });
}

/**
 * Deactivate a module and all the modules that depend on it.
 */
Drupal.contribToggleDeactivate = function (title, modules) {
  modules[title].self.attr('checked', false);
  jQuery.each(modules[title].requirements, function(i, val) {
    Drupal.contribToggleDeactivate(val, modules);
  });
}

/**
 * Parse a module's Required by, or Depends on string.
 *
 * @param: str - ex: 'Required by: Event Views (disabled), Views UI (disabled)'
 * @return: array - ex: ['Event Views', 'Views UI']
 */
Drupal.contribToggleParse = function(str) {
  var result = [];
  if (str) {
    str = str.substr(str.indexOf(':')+1); // Remove 'Required by:'
    str = str.replace( /\([^)]*\)/g, ''); // Remove (stuff).
    result = jQuery.map(str.split(','), function(n,i) {
      return jQuery.trim(n);
    });
  }
  return result;
}

Drupal.contribToggleSwitch = function () {
  // Read dependencies for all modules.
  var modules = [];
  $('#system-modules input[@type=checkbox][@name^="status"]').each( function() {
    var $row = $(this).parents('tr:first');
	var $title = $row.find('label:last').text();
	var $depend = Drupal.contribToggleParse($row.find('.admin-dependencies').text());
	var $required = Drupal.contribToggleParse($row.find('.admin-required').text());
	modules[$title] = { self: $(this), dependencies : $depend, requirements : $required }
  });
  // Disable each non-core module, and any modules that depend on it.
  $('#system-modules input[@type=checkbox][@name^="status"]').each( function() {
    // Identify package that module belongs to.
    var fieldsetLegend = $(this).parents('fieldset').find('legend').text();
    // Mark to be disabled all modules not in packages listed as cases.
    switch (fieldsetLegend) {
      case "Core - optional":
        break;
        
      case "Core - required":
        break;

      default:
        var title = $(this).parents('tr:first').find('label:last').text();
        Drupal.contribToggleDeactivate(title, modules);
    }
  });
}

if( Drupal.jsEnabled ) {
  $(document).ready(function(){ 
    // Read dependencies for all modules.
	var modules = [];
	$('#system-modules input[@type=checkbox][@name^="status"]').each( function() {
	  var $row = $(this).parents('tr:first');
	  var $title = $row.find('label:last').text();
	  var $depend = Drupal.contribToggleParse($row.find('.admin-dependencies').text());
	  var $required = Drupal.contribToggleParse($row.find('.admin-required').text());
	  modules[$title] = { self: $(this), dependencies : $depend, requirements : $required }
	});
	$('#system-modules input[@type=checkbox][@name^="status"]').click( function() {
	  var title = $(this).parents('tr:first').find('label:last').text();
	  var checked = $(this).attr('checked');
	  if (checked) { 
	    Drupal.contribToggleActivate(title, modules);
	  }
	  else {
	    Drupal.contribToggleDeactivate(title, modules);    
	  }
    });
  $(':checkbox:disabled').attr('disabled', false);
  });
}
